/***************************************************************************
                          dlg_promote.h  -  description
                             -------------------
    begin                : Fri Jul 13 2001
    copyright            : (C) 2003 by Troy Corbin Jr.
    email                : tcorbin@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DLG_PROMOTE_H
#define DLG_PROMOTE_H

#include <tdelocale.h>
#include <tqpixmap.h>
#include <tqstring.h>
#include <tqdialog.h>
#include <tqlabel.h>
#include <tqpushbutton.h>
#include "resource.h"

/**
  *@author Troy Corbin Jr.
  */

class dlg_promote : public TQDialog
{
   TQ_OBJECT
  
	public:

									dlg_promote(TQWidget *parent=0, const char *name=0, resource *Rsrc=0  );
									~dlg_promote();

		void					Init( bool Army );

	public slots:
		void					queenClick( void );
		void					bishopClick( void );
		void					knightClick( void );
		void					rookClick( void );

	private:
		resource			*Resource;
		TQLabel				*Description;
		TQPushButton	*Queen;
		TQPushButton	*Bishop;
		TQPushButton	*Knight;
		TQPushButton	*Rook;
};

#endif
